Improve this Doc

# Error: ngTransclude:orphan
Orphan ngTransclude Directive

    Illegal use of ngTransclude directive in the template! No parent directive that requires a transclusion found. Element: {0}

## Description

Occurs when an `ngTransclude` occurs without a transcluded ancestor element.

This error often occurs when you have forgotten to set `transclude: true` in some directive definition, and then used `ngTransclude` in the directive's template.

To resolve, either remove the offending `ngTransclude` or check that `transclude: true` is included in the intended directive definition.

Consult the API documentation for writing directives to learn more.